from pydantic import BaseModel


class EOIMotionDetection(BaseModel):
    periodic_check_enabled: bool = False
    periodic_check_seconds: float = 3.0
    motion_detection_enabled: bool = False
    motion_detection_threshold: int = 200
    motion_detection_seconds: float = 0.5



from pydantic import BaseModel


class EOIBoundingBox(BaseModel):
    bounding_box_enabled: bool = False
    detect_people: bool = False
    detect_vehicles: bool = False
    detect_bags: bool = False
    person_confidence_threshold: int = 30
    vehicle_confidence_threshold: int = 30
    bag_confidence_threshold: int = 30



from .eoi_genetec_alerting import EOIGenetecAlerting
from pydantic import BaseModel
from typing import Optional


class EOIAlerting(BaseModel):
    alert_seconds_count: float = 0.1
    reset_seconds_count: float = 0.1
    phone_number: Optional[str] = None
    image_notification: bool = False
    genetec: EOIGenetecAlerting = EOIGenetecAlerting()




from typing import List
from typing import Optional
from pydantic import BaseModel
from .elements.eoi_alerting import EOIAlerting
from .elements.eoi_bounding_box import EOIBoundingBox
from .elements.eoi_motion_detection import EOIMotionDetection
from .elements.eoi_object_description import EOIObjectDescription
from .elements.eoi_region import EOIRegion


class EOIAddStreamInputs(BaseModel):
    stream_url: str
    name: Optional[str] = None
    regions: List[EOIRegion]
    object_size: int = 100
    prompts: List[EOIObjectDescription]
    alerting: EOIAlerting
    efficient_detection: EOIMotionDetection = EOIMotionDetection()
    bounding_box: EOIBoundingBox = EOIBoundingBox()
    frame_rate: int = 5



import base64
from typing import List
import requests
import json
from .elements.eoi_object_description import EOIObjectDescription
from .elements.eoi_alerting import EOIAlerting
from .elements.eoi_bounding_box import EOIBoundingBox
from .elements.eoi_motion_detection import EOIMotionDetection
from .elements.eoi_region import EOIRegion
from .eoi_add_stream_inputs import EOIAddStreamInputs
from .eoi_monitor_stream_inputs import EOIMonitorStreamInputs
from .eoi_process_image_inputs import EOIProcessImageInputs
from .eoi_stream_url_input import EOIStreamUrlInput
from .eoi_response import EOIResponse
from .eoi_utils import decode_image


class EyesOnItSDK:

    def __init__(self, base_url):
        self.__base_url = base_url
        self.__process_image_path = "/process_image"
        self.__add_stream_path = "/add_stream"
        self.__remove_stream_path = "/remove_stream"
        self.__monitor_stream_path = "/monitor_stream"
        self.__stop_monitor_stream_path = "/stop_monitoring"
        self.__get_streams_info_path = "/get_streams_info"
        self.__get_last_detection_info_path = "/get_last_detection_info"
        self.__get_preview_video_frame_path = "/get_preview_video_frame"
        self.__get_video_frame_path = "/get_video_frame"
        self.__get_bounding_box_objects_path = "/get_bounding_box_objects"

    def process_image(self, object_descriptions: List[EOIObjectDescription], regions: List[EOIRegion], object_size: int, image):
        try:
            endpoint = self.__base_url + self.__process_image_path
            with open(image, "rb") as image_file:
                image = image_file.read()
            encoded_image = base64.b64encode(image).decode('utf-8')

            process_image_inputs = EOIProcessImageInputs(prompts=object_descriptions, regions=regions, object_size=object_size, file=encoded_image)
            response = requests.post(endpoint, json=process_image_inputs.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text["message"]
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def add_stream(self,
                   stream_url: str,
                   name: str,
                   regions: List[EOIRegion],
                   object_size: int,
                   object_descriptions: List[EOIObjectDescription],
                   alerting: EOIAlerting,
                   motion_detection: EOIMotionDetection = EOIMotionDetection(),
                   bounding_box: EOIBoundingBox = EOIBoundingBox(),
                   frame_rate: int = 5):
        try:
            endpoint = self.__base_url + self.__add_stream_path

            add_stream_inputs = EOIAddStreamInputs(stream_url=stream_url,
                                                   name=name,
                                                   regions=regions,
                                                   object_size=object_size,
                                                   prompts=object_descriptions,
                                                   alerting=alerting,
                                                   efficient_detection=motion_detection,
                                                   bounding_box=bounding_box,
                                                   frame_rate=frame_rate)

            response = requests.post(endpoint, json=add_stream_inputs.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text["message"]
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def monitor_stream(self, stream_url: str, duration_seconds: float = None):
        try:
            endpoint = self.__base_url + self.__monitor_stream_path
            monitor_stream_inputs = EOIMonitorStreamInputs(stream_url=stream_url, duration_seconds=duration_seconds)
            response = requests.post(endpoint, json=monitor_stream_inputs.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text["message"]
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def stop_monitoring(self, stream_url: str):
        try:
            endpoint = self.__base_url + self.__stop_monitor_stream_path
            stream_url_input = EOIStreamUrlInput(stream_url=stream_url)
            response = requests.post(endpoint, json=stream_url_input.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text["message"]
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def remove_stream(self, stream_url: str):
        try:
            endpoint = self.__base_url + self.__remove_stream_path
            stream_url_input = EOIStreamUrlInput(stream_url=stream_url)
            response = requests.post(endpoint, json=stream_url_input.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text["message"]
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def get_streams_info(self):
        try:
            endpoint = self.__base_url + self.__get_streams_info_path
            response = requests.get(endpoint)
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def get_video_frame(self, stream_url: str):
        try:
            endpoint = self.__base_url + self.__get_video_frame_path
            stream_url_input = EOIStreamUrlInput(stream_url=stream_url)
            response = requests.post(endpoint, json=stream_url_input.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                base64_image = response_text['image']
                image = decode_image(base64_image)
                response_text['image'] = image
                message = response_text
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def get_last_detection_info(self, stream_url: str):
        try:
            endpoint = self.__base_url + self.__get_last_detection_info_path
            stream_url_input = EOIStreamUrlInput(stream_url=stream_url)
            response = requests.post(endpoint, json=stream_url_input.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                base64_image = response_text['image']
                image = decode_image(base64_image)
                response_text['image'] = image
                message = response_text
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def get_preview_video_frame(self, stream_url: str):
        try:
            endpoint = self.__base_url + self.__get_preview_video_frame_path
            stream_url_input = EOIStreamUrlInput(stream_url=stream_url)
            response = requests.post(endpoint, json=stream_url_input.model_dump())
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                base64_image = response_text['image']
                image = decode_image(base64_image)
                response_text['image'] = image
                message = response_text
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))

    def get_bounding_box_objects(self):
        try:
            endpoint = self.__base_url + self.__get_bounding_box_objects_path
            response = requests.get(endpoint)
            response_text = json.loads(response.text)
            success = True if response.status_code == 200 else False

            if success:
                message = response_text
            else:
                message = response_text["detail"]

            eoi_response = EOIResponse(success, message=message)
            return eoi_response

        except Exception as e:
            return EOIResponse(success=False, message=repr(e))



from typing import List
from pydantic import BaseModel
from .elements.eoi_region import EOIRegion
from .elements.eoi_object_description import EOIObjectDescription


class EOIProcessImageInputs(BaseModel):
    prompts: List[EOIObjectDescription]
    regions: List[EOIRegion]
    object_size: int
    file: str



from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open("requirements.txt", "r", encoding="utf-8") as fh:
    install_requires = fh.read().splitlines()

setup(
    name="EyesOnIt",
    version="2.0.3",
    author="EyesOnIt",
    author_email="info@eyesonit.us",
    description="Python SDK for EyesOnIt",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/EyesOnIt-AI/EyesOnIt-python-sdk",
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    include_package_data=True,
    python_requires='>=3.8',
    install_requires=install_requires,
)



from .elements.eoi_alerting import EOIAlerting
from .elements.eoi_bounding_box import EOIBoundingBox
from .elements.eoi_motion_detection import EOIMotionDetection
from .elements.eoi_genetec_alerting import EOIGenetecAlerting
from .elements.eoi_object_description import EOIObjectDescription
from .elements.eoi_region import EOIRegion
from .eoi_add_stream_inputs import EOIAddStreamInputs
from .eoi_monitor_stream_inputs import EOIMonitorStreamInputs
from .eoi_process_image_inputs import EOIProcessImageInputs
from .eoi_stream_url_input import EOIStreamUrlInput
from .eoi_response import EOIResponse
from .eoi_utils import decode_image
from .sdk import EyesOnItSDK
